@@ -15,13 +15,13 @@ class FeatureCarrierPythonTransformer(PythonProxyBase):
         name: Optional[str] = None,
         parameters: Optional[Dict[str, Any]] = None,
         progress_logger: Optional[ProgressLogger] = None,
-        verify_count_remains_same: bool = False
+        verify_count_remains_same: bool = False,
     ) -> None:
         super().__init__(
             name=name,
             parameters=parameters,
             progress_logger=progress_logger,
-            verify_count_remains_same=verify_count_remains_same
+            verify_count_remains_same=verify_count_remains_same,
         )
         assert parameters
         assert progress_logger
